from markdown.extensions import Extension
from markdown.inlinepatterns import Pattern
from markdown.util import etree
from .icon_list import icons

fontawesome_pattern = r':fa-([-\w]+):'


class FontAwesomeException(Exception):
    'Exception for unknown icon names'
    pass


class FontAwesomePattern(Pattern):
    'Markdown pattern class for matching things that look like FA icons'
    def handleMatch(self, m):
        el = etree.Element('i')
        icon_name = m.group(2)
        if icon_name in icons:
            el.attrib = {'class': 'fa fa-{0}'.format(icon_name)}
            return el
        message = "{0} isn't a FA icon I know about".format(icon_name)
        raise FontAwesomeException(message)


class FontAwesomeExtension(Extension):
    'Pick a good spot for calling the pattern defined above'
    def extendMarkdown(self, md, md_globals):
        fontawesome = FontAwesomePattern(fontawesome_pattern)
        md.inlinePatterns.add('fontawesome', fontawesome, '<reference')



icons = \
('glass',
 'music',
 'search',
 'envelope-o',
 'heart',
 'star',
 'star-o',
 'user',
 'film',
 'th-large',
 'th',
 'th-list',
 'check',
 'times',
 'remove',
 'close',
 'search-plus',
 'search-minus',
 'power-off',
 'signal',
 'cog',
 'gear',
 'trash-o',
 'home',
 'file-o',
 'clock-o',
 'road',
 'download',
 'arrow-circle-o-down',
 'arrow-circle-o-up',
 'inbox',
 'play-circle-o',
 'repeat',
 'rotate-right',
 'refresh',
 'list-alt',
 'lock',
 'flag',
 'headphones',
 'volume-off',
 'volume-down',
 'volume-up',
 'qrcode',
 'barcode',
 'tag',
 'tags',
 'book',
 'bookmark',
 'print',
 'camera',
 'font',
 'bold',
 'italic',
 'text-height',
 'text-width',
 'align-left',
 'align-center',
 'align-right',
 'align-justify',
 'list',
 'outdent',
 'dedent',
 'indent',
 'video-camera',
 'picture-o',
 'photo',
 'image',
 'pencil',
 'map-marker',
 'adjust',
 'tint',
 'pencil-square-o',
 'edit',
 'share-square-o',
 'check-square-o',
 'arrows',
 'step-backward',
 'fast-backward',
 'backward',
 'play',
 'pause',
 'stop',
 'forward',
 'fast-forward',
 'step-forward',
 'eject',
 'chevron-left',
 'chevron-right',
 'plus-circle',
 'minus-circle',
 'times-circle',
 'check-circle',
 'question-circle',
 'info-circle',
 'crosshairs',
 'times-circle-o',
 'check-circle-o',
 'ban',
 'arrow-left',
 'arrow-right',
 'arrow-up',
 'arrow-down',
 'share',
 'mail-forward',
 'expand',
 'compress',
 'plus',
 'minus',
 'asterisk',
 'exclamation-circle',
 'gift',
 'leaf',
 'fire',
 'eye',
 'eye-slash',
 'exclamation-triangle',
 'warning',
 'plane',
 'calendar',
 'random',
 'comment',
 'magnet',
 'chevron-up',
 'chevron-down',
 'retweet',
 'shopping-cart',
 'folder',
 'folder-open',
 'arrows-v',
 'arrows-h',
 'bar-chart',
 'bar-chart-o',
 'twitter-square',
 'facebook-square',
 'camera-retro',
 'key',
 'cogs',
 'gears',
 'comments',
 'thumbs-o-up',
 'thumbs-o-down',
 'star-half',
 'heart-o',
 'sign-out',
 'linkedin-square',
 'thumb-tack',
 'external-link',
 'sign-in',
 'trophy',
 'github-square',
 'upload',
 'lemon-o',
 'phone',
 'square-o',
 'bookmark-o',
 'phone-square',
 'twitter',
 'facebook',
 'github',
 'unlock',
 'credit-card',
 'rss',
 'hdd-o',
 'bullhorn',
 'bell',
 'certificate',
 'hand-o-right',
 'hand-o-left',
 'hand-o-up',
 'hand-o-down',
 'arrow-circle-left',
 'arrow-circle-right',
 'arrow-circle-up',
 'arrow-circle-down',
 'globe',
 'wrench',
 'tasks',
 'filter',
 'briefcase',
 'arrows-alt',
 'users',
 'group',
 'link',
 'chain',
 'cloud',
 'flask',
 'scissors',
 'cut',
 'files-o',
 'copy',
 'paperclip',
 'floppy-o',
 'save',
 'square',
 'bars',
 'navicon',
 'reorder',
 'list-ul',
 'list-ol',
 'strikethrough',
 'underline',
 'table',
 'magic',
 'truck',
 'pinterest',
 'pinterest-square',
 'google-plus-square',
 'google-plus',
 'money',
 'caret-down',
 'caret-up',
 'caret-left',
 'caret-right',
 'columns',
 'sort',
 'unsorted',
 'sort-desc',
 'sort-down',
 'sort-asc',
 'sort-up',
 'envelope',
 'linkedin',
 'undo',
 'rotate-left',
 'gavel',
 'legal',
 'tachometer',
 'dashboard',
 'comment-o',
 'comments-o',
 'bolt',
 'flash',
 'sitemap',
 'umbrella',
 'clipboard',
 'paste',
 'lightbulb-o',
 'exchange',
 'cloud-download',
 'cloud-upload',
 'user-md',
 'stethoscope',
 'suitcase',
 'bell-o',
 'coffee',
 'cutlery',
 'file-text-o',
 'building-o',
 'hospital-o',
 'ambulance',
 'medkit',
 'fighter-jet',
 'beer',
 'h-square',
 'plus-square',
 'angle-double-left',
 'angle-double-right',
 'angle-double-up',
 'angle-double-down',
 'angle-left',
 'angle-right',
 'angle-up',
 'angle-down',
 'desktop',
 'laptop',
 'tablet',
 'mobile',
 'mobile-phone',
 'circle-o',
 'quote-left',
 'quote-right',
 'spinner',
 'circle',
 'reply',
 'mail-reply',
 'github-alt',
 'folder-o',
 'folder-open-o',
 'smile-o',
 'frown-o',
 'meh-o',
 'gamepad',
 'keyboard-o',
 'flag-o',
 'flag-checkered',
 'terminal',
 'code',
 'reply-all',
 'mail-reply-all',
 'star-half-o',
 'star-half-empty',
 'star-half-full',
 'location-arrow',
 'crop',
 'code-fork',
 'chain-broken',
 'unlink',
 'question',
 'info',
 'exclamation',
 'superscript',
 'subscript',
 'eraser',
 'puzzle-piece',
 'microphone',
 'microphone-slash',
 'shield',
 'calendar-o',
 'fire-extinguisher',
 'rocket',
 'maxcdn',
 'chevron-circle-left',
 'chevron-circle-right',
 'chevron-circle-up',
 'chevron-circle-down',
 'html5',
 'css3',
 'anchor',
 'unlock-alt',
 'bullseye',
 'ellipsis-h',
 'ellipsis-v',
 'rss-square',
 'play-circle',
 'ticket',
 'minus-square',
 'minus-square-o',
 'level-up',
 'level-down',
 'check-square',
 'pencil-square',
 'external-link-square',
 'share-square',
 'compass',
 'caret-square-o-down',
 'toggle-down',
 'caret-square-o-up',
 'toggle-up',
 'caret-square-o-right',
 'toggle-right',
 'eur',
 'euro',
 'gbp',
 'usd',
 'dollar',
 'inr',
 'rupee',
 'jpy',
 'cny',
 'rmb',
 'yen',
 'rub',
 'ruble',
 'rouble',
 'krw',
 'won',
 'btc',
 'bitcoin',
 'file',
 'file-text',
 'sort-alpha-asc',
 'sort-alpha-desc',
 'sort-amount-asc',
 'sort-amount-desc',
 'sort-numeric-asc',
 'sort-numeric-desc',
 'thumbs-up',
 'thumbs-down',
 'youtube-square',
 'youtube',
 'xing',
 'xing-square',
 'youtube-play',
 'dropbox',
 'stack-overflow',
 'instagram',
 'flickr',
 'adn',
 'bitbucket',
 'bitbucket-square',
 'tumblr',
 'tumblr-square',
 'long-arrow-down',
 'long-arrow-up',
 'long-arrow-left',
 'long-arrow-right',
 'apple',
 'windows',
 'android',
 'linux',
 'dribbble',
 'skype',
 'foursquare',
 'trello',
 'female',
 'male',
 'gittip',
 'sun-o',
 'moon-o',
 'archive',
 'bug',
 'vk',
 'weibo',
 'renren',
 'pagelines',
 'stack-exchange',
 'arrow-circle-o-right',
 'arrow-circle-o-left',
 'caret-square-o-left',
 'toggle-left',
 'dot-circle-o',
 'wheelchair',
 'vimeo-square',
 'try',
 'turkish-lira',
 'plus-square-o',
 'space-shuttle',
 'slack',
 'envelope-square',
 'wordpress',
 'openid',
 'university',
 'institution',
 'bank',
 'graduation-cap',
 'mortar-board',
 'yahoo',
 'google',
 'reddit',
 'reddit-square',
 'stumbleupon-circle',
 'stumbleupon',
 'delicious',
 'digg',
 'pied-piper',
 'pied-piper-alt',
 'drupal',
 'joomla',
 'language',
 'fax',
 'building',
 'child',
 'paw',
 'spoon',
 'cube',
 'cubes',
 'behance',
 'behance-square',
 'steam',
 'steam-square',
 'recycle',
 'car',
 'automobile',
 'taxi',
 'cab',
 'tree',
 'spotify',
 'deviantart',
 'soundcloud',
 'database',
 'file-pdf-o',
 'file-word-o',
 'file-excel-o',
 'file-powerpoint-o',
 'file-image-o',
 'file-photo-o',
 'file-picture-o',
 'file-archive-o',
 'file-zip-o',
 'file-audio-o',
 'file-sound-o',
 'file-video-o',
 'file-movie-o',
 'file-code-o',
 'vine',
 'codepen',
 'jsfiddle',
 'life-ring',
 'life-bouy',
 'life-buoy',
 'life-saver',
 'support',
 'circle-o-notch',
 'rebel',
 'ra',
 'empire',
 'ge',
 'git-square',
 'git',
 'hacker-news',
 'tencent-weibo',
 'qq',
 'weixin',
 'wechat',
 'paper-plane',
 'send',
 'paper-plane-o',
 'send-o',
 'history',
 'circle-thin',
 'header',
 'paragraph',
 'sliders',
 'share-alt',
 'share-alt-square',
 'bomb',
 'futbol-o',
 'soccer-ball-o',
 'tty',
 'binoculars',
 'plug',
 'slideshare',
 'twitch',
 'yelp',
 'newspaper-o',
 'wifi',
 'calculator',
 'paypal',
 'google-wallet',
 'cc-visa',
 'cc-mastercard',
 'cc-discover',
 'cc-amex',
 'cc-paypal',
 'cc-stripe',
 'bell-slash',
 'bell-slash-o',
 'trash',
 'copyright',
 'at',
 'eyedropper',
 'paint-brush',
 'birthday-cake',
 'area-chart',
 'pie-chart',
 'line-chart',
 'lastfm',
 'lastfm-square',
 'toggle-off',
 'toggle-on',
 'bicycle',
 'bus',
 'ioxhost',
 'angellist',
 'cc',
 'ils',
 'shekel',
 'sheqel',
 'meanpath')



import sys
from setuptools import setup
from setuptools.command.test import test as TestCommand


class PyTest(TestCommand):
    user_options = [('pytest-args=', 'a', "Arguments to pass to py.test")]

    def initialize_options(self):
        TestCommand.initialize_options(self)
        self.pytest_args = []

    def finalize_options(self):
        TestCommand.finalize_options(self)
        self.test_args = []
        self.test_suite = True

    def run_tests(self):
        #import here, cause outside the eggs aren't loaded
        import pytest
        errno = pytest.main(self.pytest_args)
        sys.exit(errno)

def readme():
    with open('README.rst') as f:
        return f.read()

setup(name='fontawesome-markdown',
      version='0.2.3',
      description='Font Awesome support for Markdown',
      long_description=readme(),
      url='http://bmcorser.github.com/fontawesome-markdown',
      author='bmcorser',
      author_email='benmarshallcorser@gmail.com',
      license='GPL',
      packages=['fontawesome_markdown'],
      install_requires=['markdown'],
      tests_require=['pytest'],
      cmdclass={'test': PyTest},
      zip_safe=False)
